==> pynex-0.0.1.tar.gz: pynex-0.0.1/pynex/checkbox_animated.py <==
import pygame
from . import *


class NCheckBoxAnimated:
    def __init__(
            self,
            parent: any,
            font: pygame.font.Font,
            xy: tuple,
            text: str,
            color: tuple = (0, 0, 0),
            animation_time: any = 0.2,
            auto_size: bool = True,
            auto_size_box: bool = False,
            anti_alias: bool = True,
            stretch: bool = False
    ) -> None:
        super(NCheckBoxAnimated, self).__init__()
        self.font = font
        self.x, self.y = xy
        self.w, self.h = 0, 0
        self._width, self._height = self.w, self.h
        self.anti_alias = anti_alias
        self.auto_size = auto_size
        self.auto_size_box = auto_size_box
        self.stretch = stretch
        self.hook_mouse = True
        self.is_visible = True
        self.is_enabled = True
        self.is_focusable = True
        self.enable_scroll = True
        self.usable = True
        self.text = text
        self.x_offset = 0
        self.y_offset = 0
        self.animation_time = float(animation_time)
        self.color1 = (255, 255, 255)
        self.color2 = (51, 51, 51)
        self.color3 = self.color2
        self.color1_hover = (255, 255, 255)
        self.color2_hover = (0, 120, 215)
        self.color3_hover = self.color2_hover
        self.color1_focus = (204, 228, 247)
        self.color2_focus = (0, 84, 153)
        self.color3_focus = self.color2_focus
        self.current_color1 = NSimpleColorFade(None, self.color1, self.color1, self.animation_time, False)
        self.current_color2 = NSimpleColorFade(None, self.color2, self.color2, self.animation_time, False)
        self.current_color3 = NSimpleColorFade(None, self.color3, self.color3, self.animation_time, False)
        self.border_radius = 0
        self.padding = 3
        self.box_size = 13
        self.margin = 5
        self.checked = False
        self.multi_lines_align = LABEL_ALIGN_LEFT
        self.surface: pygame.Surface = None  # type: ignore
        self.cursor = cursors.get('DEFAULT')
        self.color = color
        self.z_order = 0
        self.tag = ''
        self.id = ''
        self.set('text', text)
        if parent:
            parent.add_child(self)

    def set(self, name: str, value: any) -> any:
        setattr(self, name, value)
        if name in ('text', 'color', 'anti_alias', 'mutli_line_align', 'stretch', 'auto_size'):
            self.redraw()
        return self

    def redraw(self) -> None:
        if self.text.count('\n') <= 0:
            self.surface = self.font.render(
                self.text,
                self.anti_alias,
                self.color
            )
            self._width, self._height = self.surface.get_size()
            if self.auto_size:
                self.w, self.h = self._width, self._height
            elif self.stretch:
                self.surface = pygame.transform.scale(self.surface, (self.w, self.h))
            if self.auto_size_box:
                self.box_size = self.h
            return
        total_height = 0
        max_width = 0
        surfaces = []
        heights = []
        for _text in self.text.split('\n'):
            _surface = self.font.render(
                _text,
                self.anti_alias,
                self.color
            )
            total_height += _surface.get_height()
            max_width = max(max_width, _surface.get_width())
            surfaces.append(_surface)
            heights.append(_surface.get_height())
        self._width, self._height = max_width, total_height
        self.surface = pygame.Surface((max_width, total_height), pygame.SRCALPHA, 32)
        total_height = 0
        for _num, _surface in enumerate(surfaces):
            self.surface.blit(
                _surface, (
                    0 if self.multi_lines_align == LABEL_ALIGN_LEFT else (
                        max_width - _surface.get_width() if self.multi_lines_align == LABEL_ALIGN_RIGHT else
                        round(max_width / 2 - _surface.get_width() / 2)
                    ),
                    total_height
                )
            )
            total_height += heights[_num]
        if self.auto_size:
            self.w, self.h = self._width, self._height
        elif self.stretch:
            self.surface = pygame.transform.scale(self.surface, (self.w, self.h))
        if self.auto_size_box:
            self.box_size = self.h

    def draw(self, surface: pygame.Surface, delta: float, scroll_x: int, scroll_y: int) -> None:
        if not self.is_visible:
            return
        if not self.enable_scroll:
            scroll_x = scroll_y = 0
        self.current_color1.draw(surface, delta, scroll_x, scroll_y)
        self.current_color2.draw(surface, delta, scroll_x, scroll_y)
        self.current_color3.draw(surface, delta, scroll_x, scroll_y)
        pygame.draw.rect(
            surface,
            self.current_color1.color,
            (self.x + scroll_x, self.y + scroll_y, self.box_size, self.box_size),
            0,
            self.border_radius
        )
        if self.checked:
            pygame.draw.rect(
                surface,
                self.current_color3.color,
                (
                    self.x + scroll_x + self.padding,
                    self.y + scroll_y + self.padding,
                    self.box_size - self.padding * 2,
                    self.box_size - self.padding * 2
                ),
                0,
                self.border_radius
            )
        pygame.draw.rect(
            surface,
            self.current_color2.color,
            (self.x + scroll_x, self.y + scroll_y, self.box_size, self.box_size),
            1,
            self.border_radius
        )
        surface.blit(
            self.surface,
            (self.box_size + self.margin + self.x + self.x_offset + scroll_x, self.y + self.y_offset + scroll_y),
            None if self.auto_size else (0, 0, self.w - 1, self.h)
        )

    def _on_mouse_wheel(self, event: pygame.event.Event, bind: bool) -> None:
        if bind:
            self.on_mouse_wheel(  # type: ignore
                (event.x, event.y), hasattr(event, 'touch') and event.touch, event.flipped
            )

    def _on_mouse_leave(self, event: pygame.event.Event, bind: bool) -> None:
        self.current_color1.create(self.current_color1.color, self.color1, self.animation_time)
        self.current_color2.create(self.current_color2.color, self.color2, self.animation_time)
        self.current_color3.create(self.current_color3.color, self.color3, self.animation_time)
        if bind:
            self.on_mouse_leave(event.pos)  # type: ignore

    def _on_mouse_enter(self, event: pygame.event.Event, bind: bool) -> None:
        self.current_color1.create(self.current_color1.color, self.color1_hover, self.animation_time)
        self.current_color2.create(self.current_color2.color, self.color2_hover, self.animation_time)
        self.current_color3.create(self.current_color3.color, self.color3_hover, self.animation_time)
        if bind:
            self.on_mouse_enter(event.pos)  # type: ignore

    def _on_mouse_move(self, event: pygame.event.Event, bind: bool) -> None:
        if bind:
            self.on_mouse_move(  # type: ignore
                event.pos, event.rel, event.buttons, hasattr(event, 'touch') and event.touch
            )

    def _on_mouse_down(self, event: pygame.event.Event, bind: bool) -> None:
        if event.button == pygame.BUTTON_LEFT:
            self.current_color1.create(self.current_color1.color, self.color1_focus, self.animation_time)
            self.current_color2.create(self.current_color2.color, self.color2_focus, self.animation_time)
            self.current_color3.create(self.current_color3.color, self.color3_focus, self.animation_time)
        if bind:
            self.on_mouse_down(event.pos, event.button)  # type: ignore

    def _on_mouse_up(self, event: pygame.event.Event, bind: bool) -> None:
        if bind:
            self.on_mouse_up(event.pos, event.button)  # type: ignore
        if event.button == pygame.BUTTON_LEFT:
            self.current_color1.create(self.current_color1.color, self.color1_hover, self.animation_time)
            self.current_color2.create(self.current_color2.color, self.color2_hover, self.animation_time)
            self.current_color3.create(self.current_color3.color, self.color3_hover, self.animation_time)
            if self.checked:
                self.checked = False
            else:
                self.checked = True
            if hasattr(self, 'on_check'):
                self.on_check(self.checked)
            if hasattr(self, 'on_click'):
                self.on_click(event.pos)

    def _on_focus_enter(self, event: pygame.event.Event, bind: bool) -> None:
        if bind:
            self.on_focus_enter(event.pos, event.button)  # type: ignore

    def _on_focus_leave(self, event: pygame.event.Event, bind: bool) -> None:
        if bind:
            self.on_focus_leave(event.pos, event.button)  # type: ignore

    def _on_key_down(self, event: pygame.event.Event, bind: bool) -> None:
        if bind:
            self.on_key_down(event)  # type: ignore

    def _on_key_up(self, event: pygame.event.Event, bind: bool) -> None:
        if bind:
            self.on_key_up(event)  # type: ignore

    def __bool__(self) -> bool:
        return self.checked

==> pynex-0.0.7.tar.gz: pynex-0.0.7/pynex/checkbox_animated.py <==
import pygame
from . import *


class NAnimatedCheckBox:
    def __init__(
            self,
            parent: any,
            font: pygame.font.Font,
            xy: tuple,
            text: str,
            color: tuple = (0, 0, 0),
            animation_time: any = 0.2,
            auto_size: bool = True,
            auto_size_box: bool = False,
            anti_alias: bool = True,
            stretch: bool = False
    ) -> None:
        super(NAnimatedCheckBox, self).__init__()
        self.font = font
        self.x, self.y = xy
        self.w, self.h = 0, 0
        self._width, self._height = self.w, self.h
        self.anti_alias = anti_alias
        self.auto_size = auto_size
        self.auto_size_box = auto_size_box
        self.stretch = stretch
        self.hook_mouse = True
        self.is_visible = True
        self.is_enabled = True
        self.is_focusable = True
        self.enable_scroll = True
        self.usable = True
        self.text = text
        self.x_offset = 0
        self.y_offset = 0
        self.animation_time = float(animation_time)
        self.color1 = (255, 255, 255)
        self.color2 = (51, 51, 51)
        self.color3 = self.color2
        self.color1_hover = (255, 255, 255)
        self.color2_hover = (0, 120, 215)
        self.color3_hover = self.color2_hover
        self.color1_focus = (204, 228, 247)
        self.color2_focus = (0, 84, 153)
        self.color3_focus = self.color2_focus
        self.current_color1 = NSimpleColorFade(None, self.color1, self.color1, self.animation_time, False)
        self.current_color2 = NSimpleColorFade(None, self.color2, self.color2, self.animation_time, False)
        self.current_color3 = NSimpleColorFade(None, self.color3, self.color3, self.animation_time, False)
        self.border_radius = 0
        self.padding = 3
        self.box_size = 13
        self.margin = 5
        self.checked = False
        self.multi_lines_align = LABEL_ALIGN_LEFT
        self.surface: pygame.Surface = None  # type: ignore
        self.cursor = cursors.get('DEFAULT')
        self.color = color
        self.z_order = 0
        self.tag = ''
        self.id = ''
        self.set('text', text)
        if parent:
            parent.add_child(self)

    def set(self, name: str, value: any) -> any:
        setattr(self, name, value)
        if name in ('text', 'color', 'anti_alias', 'mutli_line_align', 'stretch', 'auto_size'):
            self.redraw()
        return self

    def redraw(self) -> None:
        if self.text.count('\n') <= 0:
            self.surface = self.font.render(
                self.text,
                self.anti_alias,
                self.color
            )
            self._width, self._height = self.surface.get_size()
            if self.auto_size:
                self.w, self.h = self._width, self._height
            elif self.stretch:
                self.surface = pygame.transform.scale(self.surface, (self.w, self.h))
            if self.auto_size_box:
                self.box_size = self.h
            return
        total_height = 0
        max_width = 0
        surfaces = []
        heights = []
        for _text in self.text.split('\n'):
            _surface = self.font.render(
                _text,
                self.anti_alias,
                self.color
            )
            total_height += _surface.get_height()
            max_width = max(max_width, _surface.get_width())
            surfaces.append(_surface)
            heights.append(_surface.get_height())
        self._width, self._height = max_width, total_height
        self.surface = pygame.Surface((max_width, total_height), pygame.SRCALPHA, 32)
        total_height = 0
        for _num, _surface in enumerate(surfaces):
            self.surface.blit(
                _surface, (
                    0 if self.multi_lines_align == LABEL_ALIGN_LEFT else (
                        max_width - _surface.get_width() if self.multi_lines_align == LABEL_ALIGN_RIGHT else
                        round(max_width / 2 - _surface.get_width() / 2)
                    ),
                    total_height
                )
            )
            total_height += heights[_num]
        if self.auto_size:
            self.w, self.h = self._width, self._height
        elif self.stretch:
            self.surface = pygame.transform.scale(self.surface, (self.w, self.h))
        if self.auto_size_box:
            self.box_size = self.h

    def draw(self, surface: pygame.Surface, delta: float, scroll_x: int, scroll_y: int) -> None:
        if not self.is_visible:
            return
        if not self.enable_scroll:
            scroll_x = scroll_y = 0
        self.current_color1.draw(surface, delta, scroll_x, scroll_y)
        self.current_color2.draw(surface, delta, scroll_x, scroll_y)
        self.current_color3.draw(surface, delta, scroll_x, scroll_y)
        pygame.draw.rect(
            surface,
            self.current_color1.color,
            (self.x + scroll_x, self.y + scroll_y, self.box_size, self.box_size),
            0,
            self.border_radius
        )
        if self.checked:
            pygame.draw.rect(
                surface,
                self.current_color3.color,
                (
                    self.x + scroll_x + self.padding,
                    self.y + scroll_y + self.padding,
                    self.box_size - self.padding * 2,
                    self.box_size - self.padding * 2
                ),
                0,
                self.border_radius
            )
        pygame.draw.rect(
            surface,
            self.current_color2.color,
            (self.x + scroll_x, self.y + scroll_y, self.box_size, self.box_size),
            1,
            self.border_radius
        )
        surface.blit(
            self.surface,
            (self.box_size + self.margin + self.x + self.x_offset + scroll_x, self.y + self.y_offset + scroll_y),
            None if self.auto_size else (0, 0, self.w - 1, self.h)
        )

    def _on_mouse_wheel(self, event: pygame.event.Event, bind: bool) -> None:
        if bind:
            self.on_mouse_wheel(  # type: ignore
                (event.x, event.y), hasattr(event, 'touch') and event.touch, event.flipped
            )

    def _on_mouse_leave(self, event: pygame.event.Event, bind: bool) -> None:
        self.current_color1.create(self.current_color1.color, self.color1, self.animation_time)
        self.current_color2.create(self.current_color2.color, self.color2, self.animation_time)
        self.current_color3.create(self.current_color3.color, self.color3, self.animation_time)
        if bind:
            self.on_mouse_leave(event.pos)  # type: ignore

    def _on_mouse_enter(self, event: pygame.event.Event, bind: bool) -> None:
        self.current_color1.create(self.current_color1.color, self.color1_hover, self.animation_time)
        self.current_color2.create(self.current_color2.color, self.color2_hover, self.animation_time)
        self.current_color3.create(self.current_color3.color, self.color3_hover, self.animation_time)
        if bind:
            self.on_mouse_enter(event.pos)  # type: ignore

    def _on_mouse_move(self, event: pygame.event.Event, bind: bool) -> None:
        if bind:
            self.on_mouse_move(  # type: ignore
                event.pos, event.rel, event.buttons, hasattr(event, 'touch') and event.touch
            )

    def _on_mouse_down(self, event: pygame.event.Event, bind: bool) -> None:
        if event.button == pygame.BUTTON_LEFT:
            self.current_color1.create(self.current_color1.color, self.color1_focus, self.animation_time)
            self.current_color2.create(self.current_color2.color, self.color2_focus, self.animation_time)
            self.current_color3.create(self.current_color3.color, self.color3_focus, self.animation_time)
        if bind:
            self.on_mouse_down(event.pos, event.button)  # type: ignore

    def _on_mouse_up(self, event: pygame.event.Event, bind: bool) -> None:
        if bind:
            self.on_mouse_up(event.pos, event.button)  # type: ignore
        if event.button == pygame.BUTTON_LEFT:
            self.current_color1.create(self.current_color1.color, self.color1_hover, self.animation_time)
            self.current_color2.create(self.current_color2.color, self.color2_hover, self.animation_time)
            self.current_color3.create(self.current_color3.color, self.color3_hover, self.animation_time)
            if self.checked:
                self.checked = False
            else:
                self.checked = True
            if hasattr(self, 'on_check'):
                self.on_check(self.checked)
            if hasattr(self, 'on_click'):
                self.on_click(event.pos)

    def _on_focus_enter(self, event: pygame.event.Event, bind: bool) -> None:
        if bind:
            self.on_focus_enter(event.pos, event.button)  # type: ignore

    def _on_focus_leave(self, event: pygame.event.Event, bind: bool) -> None:
        if bind:
            self.on_focus_leave(event.pos, event.button)  # type: ignore

    def _on_key_down(self, event: pygame.event.Event, bind: bool) -> None:
        if bind:
            self.on_key_down(event)  # type: ignore

    def _on_key_up(self, event: pygame.event.Event, bind: bool) -> None:
        if bind:
            self.on_key_up(event)  # type: ignore

    def __bool__(self) -> bool:
        return self.checked
